@@ -134,6 +134,7 @@ SessionController::SessionController(Session *sessionParam, TerminalDisplay *vie
     , _isSearchBarEnabled(false)
     , _searchBar(viewParam->searchBar())
     , _monitorProcessFinish(false)
+    , _monitorOnce(false)
     , _escapedUrlFilter(nullptr)
 {
     Q_ASSERT(sessionParam);
@@ -365,6 +366,9 @@ void SessionController::snapshot()
             connect(notification, &KNotification::defaultActivated, this, [this, notification]() {
                 view()->notificationClicked(notification->xdgActivationToken());
             });
+            if (_monitorOnce) {
+                actionCollection()->action(QStringLiteral("monitor-process-finish"))->setChecked(false);
+            }
         }
         _previousForegroundProcessName = isForegroundProcessActive ? session()->foregroundProcessName() : QString();
     }
@@ -567,7 +571,11 @@ void SessionController::handleWebShortcutAction(QAction *action)
 
 void SessionController::configureWebShortcuts()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {QStringLiteral("webshortcuts")});
+#else
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell6"), {QStringLiteral("webshortcuts")});
+#endif
     job->start();
 }
 
@@ -804,9 +812,14 @@ void SessionController::setupCommonActions()
             this,
 #endif
             &Konsole::SessionController::changeCodec);
+#else
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    connect(_codecAction, &KCodecAction::codecNameTriggered, this, [this](const QByteArray &codecName) {
+        changeCodec(QTextCodec::codecForName(codecName));
 #else
     connect(_codecAction, &KCodecAction::codecNameTriggered, this, [this](const QString &codecName) {
         changeCodec(QTextCodec::codecForName(codecName.toUtf8()));
+#endif
     });
 #endif
 
@@ -872,7 +885,11 @@ void SessionController::setupExtraActions()
     copyInputActions->addAction(copyInputToAllTabsAction);
     copyInputActions->addAction(copyInputToSelectedTabsAction);
     copyInputActions->addAction(copyInputToNoneAction);
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    connect(copyInputActions, &KSelectAction::actionTriggered, this, &Konsole::SessionController::copyInputActionsTriggered);
+#else
     connect(copyInputActions, QOverload<QAction *>::of(&KSelectAction::triggered), this, &Konsole::SessionController::copyInputActionsTriggered);
+#endif
 
     action = collection->addAction(QStringLiteral("zmodem-upload"), this, &SessionController::zmodemUpload);
     action->setText(i18n("&ZModem Upload..."));
@@ -880,7 +897,19 @@ void SessionController::setupExtraActions()
     collection->setDefaultShortcut(action, Qt::CTRL | Qt::ALT | Qt::Key_U);
 
     // Monitor
-    KToggleAction *toggleAction = new KToggleAction(i18n("Monitor for &Activity"), this);
+    KToggleAction *toggleAction = new KToggleAction(i18n("One-shot monitors"), this);
+    action = collection->addAction(QStringLiteral("monitor-once"), toggleAction);
+    connect(action, &QAction::toggled, this, &Konsole::SessionController::monitorOnce);
+    action->setIcon(QIcon::fromTheme(QStringLiteral("tools-media-optical-burn")));
+
+    toggleAction = new KToggleAction(i18n("Monitor for &Prompt"), this);
+    collection->setDefaultShortcut(toggleAction, Konsole::ACCEL | Qt::Key_R);
+    action = collection->addAction(QStringLiteral("monitor-prompt"), toggleAction);
+    connect(action, &QAction::toggled, this, &Konsole::SessionController::monitorPrompt);
+    action->setIcon(QIcon::fromTheme(QStringLiteral("tools-media-optical-burn")));
+    action->setVisible(false);
+
+    toggleAction = new KToggleAction(i18n("Monitor for &Activity"), this);
     collection->setDefaultShortcut(toggleAction, Konsole::ACCEL | Qt::Key_A);
     action = collection->addAction(QStringLiteral("monitor-activity"), toggleAction);
     connect(action, &QAction::toggled, this, &Konsole::SessionController::monitorActivity);
@@ -919,7 +948,11 @@ void SessionController::setupExtraActions()
     // Send signal
     auto *sendSignalActions = collection->add<KSelectAction>(QStringLiteral("send-signal"));
     sendSignalActions->setText(i18n("Send Signal"));
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    connect(sendSignalActions, &KSelectAction::actionTriggered, this, &Konsole::SessionController::sendSignal);
+#else
     connect(sendSignalActions, QOverload<QAction *>::of(&KSelectAction::triggered), this, &Konsole::SessionController::sendSignal);
+#endif
 
     action = collection->addAction(QStringLiteral("sigstop-signal"));
     action->setText(i18n("&Suspend Task") + QStringLiteral(" (STOP)"));
@@ -1521,6 +1554,7 @@ void SessionController::searchBarEvent()
         _searchBar->focusLineEdit();
     } else {
         searchHistory(true);
+        searchTextChanged(_searchBar->searchText());
         _isSearchBarEnabled = true;
     }
 }
@@ -1611,11 +1645,12 @@ void SessionController::setFindNextPrevEnabled(bool enabled)
     _findNextAction->setEnabled(enabled);
     _findPreviousAction->setEnabled(enabled);
 }
+
 void SessionController::searchTextChanged(const QString &text)
 {
     Q_ASSERT(view()->screenWindow());
 
-    if (_searchText == text) {
+    if (_searchText == text && _isSearchBarEnabled) {
         return;
     }
 
@@ -1821,6 +1856,31 @@ void SessionController::resetFontSize()
     view()->terminalFont()->resetFontSize();
 }
 
+void SessionController::notifyPrompt()
+{
+    if (session()->isMonitorPrompt()) {
+        KNotification *notification = KNotification::event(session()->hasFocus() ? QStringLiteral("Prompt") : QStringLiteral("PromptHidden"),
+                                                           i18n("The shell prompt is displayed in session '%1'", session()->nameTitle()),
+                                                           QPixmap(),
+                                                           view(),
+                                                           KNotification::CloseWhenWidgetActivated);
+        notification->setDefaultAction(i18n("Show session"));
+        connect(notification, &KNotification::defaultActivated, this, [this, notification]() {
+            view()->notificationClicked(notification->xdgActivationToken());
+        });
+        if (_monitorOnce) {
+            actionCollection()->action(QStringLiteral("monitor-prompt"))->setChecked(false);
+        }
+    }
+}
+void SessionController::monitorOnce(bool once)
+{
+    _monitorOnce = once;
+}
+void SessionController::monitorPrompt(bool monitor)
+{
+    session()->setMonitorPrompt(monitor);
+}
 void SessionController::monitorActivity(bool monitor)
 {
     session()->setMonitorActivity(monitor);
@@ -2128,3 +2188,8 @@ bool SessionController::isValid() const
 {
     return _sessionDisplayConnection->isValid();
 }
+
+void SessionController::setVisible(QString name, bool visible)
+{
+    actionCollection()->action(name)->setVisible(visible);
+}
