@@ -147,6 +147,16 @@ public:
     /* Set/reset selection mode */
     void setSelectMode(bool mode);
 
+    /* Send notification when a shell prompt is displayed */
+    void notifyPrompt();
+
+    void setVisible(QString name, bool visible);
+
+    bool isMonitorOnce() const
+    {
+        return _monitorOnce;
+    };
+
 Q_SIGNALS:
     /**
      * Emitted when the view associated with the controller is focused.
@@ -260,6 +270,8 @@ private Q_SLOTS:
     void showHistoryOptions();
     void clearHistory();
     void clearHistoryAndReset();
+    void monitorOnce(bool once);
+    void monitorPrompt(bool monitor);
     void monitorActivity(bool monitor);
     void monitorSilence(bool monitor);
     void monitorProcessFinish(bool monitor);
@@ -384,6 +396,7 @@ private:
 
     QString _previousForegroundProcessName;
     bool _monitorProcessFinish;
+    bool _monitorOnce;
     EscapeSequenceUrlFilter *_escapedUrlFilter;
 
     std::unique_ptr<KXMLGUIBuilder> _clientBuilder;
